#!/bin/env python
"""
 CC128 RRD Logger
==================
Author: Paul Banks

Create graphs from output directory

Usage:

    CC2MakeGraphs.py -d datadir -o outputdir

"""
# If you have the python RRDTool module installed in a non-site place
# Uncomment below and update path
import sys
#sys.path.append('/opt/rrdtool-1.4.4/lib/python2.6/site-packages/')

import os
import getopt

try:
    import rrdtool
except ImportError:
    print """    Failed to import python RRDTool module. Is it installed?
    You may need to update the path if installed in a non-standard place."""
    sys.exit(3)

def MakeGraph(outfile, rrdfile, dataset):
    rrdtool.graph(
        outfile,
        "--end", "now",
        "--start", "end-50000s",
        "--width", "1024",
        "--height", "400",
        "--disable-rrdtool-tag", # Credit due but no badge-ware
        "-W", "Blah",
        "DEF:ds0=%s:%s:AVERAGE" % (rrdfile, dataset),
        "LINE1:ds0#ff0000"
    )

def MakeGraphs(datadir, outdir):

    files = os.listdir(datadir)

    for f in files:
        if f.startswith("rrd_"):
            MakeGraph(
                 os.path.join(outdir, "img_%s.png" % f),
                 os.path.join(datadir, f),
                 "chdata"
            )



def Usage():
    print __doc__

def Main():

    # Get command line args
    try:
        opts, args = getopt.getopt(sys.argv[1:], "hd:o:")
    except getopt.GetoptError, err:
        print str(err)
        Usage()
        sys.exit(2)

    # Process args
    datadir = None
    outdir = None
    for o, a in opts:
        if o == "-h":
            Usage()
            sys.exit(0)         
        if o == "-d":
            datadir = a
        elif o == "-o":
            outdir = a

    if datadir==None or outdir==None:
        print "You must specify both input data directory and output directory for graphs"
        sys.exit(1)

    MakeGraphs(datadir, outdir)


if __name__=="__main__":
    Main()
